Contributing
============

Basic Information
-----------------

.. toctree::
   :maxdepth: 3

   contributing

Testing
-------

Manilaclient has two types of tests - 'unit' and 'functional'.

The preferred way to run tests is using ``tox``.

See `Consistent Testing Interface`_ for more details.

.. toctree::
    :maxdepth: 3

    functional-tests

.. _Consistent Testing Interface: https://opendev.org/openstack/governance/src/branch/master/reference/project-testing-interface.rst